@@ -300,6 +300,7 @@ void bind_session()
         .def("stop_dht", allow_threads(&session::stop_dht), session_stop_dht_doc)
         .def("dht_state", allow_threads(&session::dht_state), session_dht_state_doc)
         .def("set_dht_proxy", allow_threads(&session::set_dht_proxy))
+        .def("dht_proxy", allow_threads(&session::dht_proxy), return_value_policy<copy_const_reference>())
 #endif
         .def("add_torrent", &add_torrent, session_add_torrent_doc)
 #ifndef TORRENT_NO_DEPRECATE
@@ -373,6 +374,9 @@ void bind_session()
         .def("set_peer_proxy", allow_threads(&session::set_peer_proxy))
         .def("set_tracker_proxy", allow_threads(&session::set_tracker_proxy))
         .def("set_web_seed_proxy", allow_threads(&session::set_web_seed_proxy))
+        .def("peer_proxy", allow_threads(&session::peer_proxy), return_value_policy<copy_const_reference>())
+        .def("tracker_proxy", allow_threads(&session::tracker_proxy), return_value_policy<copy_const_reference>())
+        .def("web_seed_proxy", allow_threads(&session::web_seed_proxy), return_value_policy<copy_const_reference>())
         .def("start_upnp", &start_upnp, session_start_upnp_doc)
         .def("stop_upnp", allow_threads(&session::stop_upnp), session_stop_upnp_doc)
         .def("start_lsd", allow_threads(&session::start_lsd), session_start_lsd_doc)
@@ -385,6 +389,7 @@ void bind_session()
         .def("pause", allow_threads(&session::pause))
         .def("resume", allow_threads(&session::resume))
         .def("is_paused", allow_threads(&session::is_paused))
+        .def("id", allow_threads(&session::id))
         ;
 
     register_ptr_to_python<std::auto_ptr<alert> >();
