@@ -78,6 +78,10 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "libtorrent/disk_buffer_holder.hpp"
 #include "libtorrent/bitfield.hpp"
 
+#ifdef TORRENT_STATS
+#include "libtorrent/aux_/session_impl.hpp"
+#endif
+
 namespace libtorrent
 {
 	class torrent;
@@ -396,7 +400,7 @@ namespace libtorrent
 		void assign_bandwidth(int channel, int amount);
 		void expire_bandwidth(int channel, int amount);
 
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		void check_invariant() const;
 		ptime m_last_choke;
 #endif
@@ -458,7 +462,7 @@ namespace libtorrent
 		bool packet_finished() const
 		{ return m_packet_size <= m_recv_pos; }
 
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		bool piece_failed;
 #endif
 
@@ -566,7 +570,7 @@ namespace libtorrent
 		char m_country[2];
 #endif
 
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		boost::intrusive_ptr<peer_connection> self()
 		{
 			TORRENT_ASSERT(!m_in_constructor);
@@ -870,7 +874,7 @@ namespace libtorrent
 		// this is set to true once the bitfield is received
 		bool m_bitfield_received:1;
 
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 	public:
 		bool m_in_constructor:1;
 		bool m_disconnect_started:1;
