@@ -143,6 +143,7 @@ namespace libtorrent
 			, min_announce_interval(5 * 60)
 			, prioritize_partial_pieces(false)
 			, auto_manage_startup(120)
+			, rate_limit_ip_overhead(true)
 		{}
 
 		// this is the user agent that will be sent to the tracker
@@ -450,6 +451,11 @@ namespace libtorrent
 		// inactive until they have a fair chance to
 		// start downloading.
 		int auto_manage_startup;
+
+		// if set to true, the estimated TCP/IP overhead is
+		// drained from the rate limiters, to avoid exceeding
+		// the limits with the total traffic
+		bool rate_limit_ip_overhead;
 	};
 
 #ifndef TORRENT_DISABLE_DHT
