@@ -51,6 +51,7 @@ namespace libtorrent
 			, udp::endpoint const&, char const* buf, int size)> callback_t;
 
 		udp_socket(io_service& ios, callback_t const& c, connection_queue& cc);
+		~udp_socket();
 
 		bool is_open() const { return m_ipv4_sock.is_open() || m_ipv6_sock.is_open(); }
 		io_service& get_io_service() { return m_ipv4_sock.get_io_service(); }
@@ -64,10 +65,6 @@ namespace libtorrent
 		void set_proxy_settings(proxy_settings const& ps);
 		proxy_settings const& get_proxy_settings() { return m_proxy_settings; }
 
-#ifndef NDEBUG
-		~udp_socket() { m_magic = 0; }
-#endif
-
 	private:
 
 		callback_t m_callback;
@@ -107,8 +104,9 @@ namespace libtorrent
 		tcp::resolver m_resolver;
 		char m_tmp_buf[100];
 		bool m_tunnel_packets;
+		bool m_abort;
 		udp::endpoint m_proxy_addr;
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		int m_magic;
 #endif
 	};
