@@ -41,10 +41,6 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <windows.h>
 #include <winioctl.h>
 
-#ifdef UNICODE
-#include "libtorrent/storage.hpp"
-#endif
-
 #else
 // posix part
 #define _FILE_OFFSET_BITS 64
@@ -75,7 +71,8 @@ BOOST_STATIC_ASSERT(sizeof(lseek(0, 0, 0)) >= 8);
 #define O_RANDOM 0
 #endif
 
-#ifdef UNICODE
+#ifdef TORRENT_USE_WPATH
+// for safe_convert
 #include "libtorrent/storage.hpp"
 #endif
 
@@ -142,7 +139,7 @@ namespace libtorrent
 #else
 		: m_fd(-1)
 #endif
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		, m_open_mode(0)
 #endif
 	{}
@@ -153,7 +150,7 @@ namespace libtorrent
 #else
 		: m_fd(-1)
 #endif
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		, m_open_mode(0)
 #endif
 	{
@@ -170,10 +167,10 @@ namespace libtorrent
 		close();
 #ifdef TORRENT_WINDOWS
 
-#ifdef UNICODE
-		std::wstring file_path(safe_convert(path.native_file_string()));
+#ifdef TORRENT_USE_WPATH
+		std::wstring file_path(safe_convert(path.external_file_string()));
 #else
-		std::string file_path = utf8_native(path.native_file_string());
+		std::string file_path = utf8_native(path.external_file_string());
 #endif
 
 		m_file_handle = CreateFile(
@@ -205,7 +202,7 @@ namespace libtorrent
 			| S_IRGRP | S_IWGRP
 			| S_IROTH | S_IWOTH;
 
-		m_fd = ::open(path.native_file_string().c_str()
+		m_fd = ::open(path.external_file_string().c_str()
 			, map_open_mode(mode.m_mask), permissions);
 
 		if (m_fd == -1)
@@ -214,7 +211,7 @@ namespace libtorrent
 			return false;
 		}
 #endif
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		m_open_mode = mode;
 #endif
 		TORRENT_ASSERT(is_open());
@@ -241,7 +238,7 @@ namespace libtorrent
 		::close(m_fd);
 		m_fd = -1;
 #endif
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		m_open_mode = 0;
 #endif
 	}
