@@ -34,6 +34,7 @@ POSSIBILITY OF SUCH DAMAGE.
 
 #include <cctype>
 #include <algorithm>
+#include <stdio.h>
 
 #ifdef _MSC_VER
 #pragma warning(push, 1)
@@ -47,6 +48,7 @@ POSSIBILITY OF SUCH DAMAGE.
 
 #include "libtorrent/identify_client.hpp"
 #include "libtorrent/fingerprint.hpp"
+#include "libtorrent/escape_string.hpp"
 
 namespace
 {
@@ -55,15 +57,10 @@ namespace
 
 	int decode_digit(char c)
 	{
-		if (std::isdigit(c)) return c - '0';
+		if (is_digit(c)) return c - '0';
 		return unsigned(c) - 'A' + 10;
 	}
 
-	bool isprint(char c)
-	{
-		return c >= 32 && c < 127;
-	}
-
 	// takes a peer id and returns a valid boost::optional
 	// object if the peer id matched the azureus style encoding
 	// the returned fingerprint contains information about the
@@ -271,7 +268,7 @@ namespace
 			std::lower_bound(name_map, name_map + size
 				, tmp, &compare_id);
 
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 		for (int i = 1; i < size; ++i)
 		{
 			TORRENT_ASSERT(compare_id(name_map[i-1]
