@@ -1,8 +1,40 @@
+/*
+
+Copyright (c) 2007, Arvid Norberg
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+    * Redistributions of source code must retain the above copyright
+      notice, this list of conditions and the following disclaimer.
+    * Redistributions in binary form must reproduce the above copyright
+      notice, this list of conditions and the following disclaimer in
+      the documentation and/or other materials provided with the distribution.
+    * Neither the name of the author nor the names of its
+      contributors may be used to endorse or promote products derived
+      from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+POSSIBILITY OF SUCH DAMAGE.
+
+*/
+
 #include "libtorrent/udp_socket.hpp"
 #include "libtorrent/connection_queue.hpp"
+#include "libtorrent/escape_string.hpp"
 #include <stdlib.h>
 #include <boost/bind.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/array.hpp>
 #if BOOST_VERSION < 103500
 #include <asio/read.hpp>
@@ -24,13 +56,24 @@ udp_socket::udp_socket(asio::io_service& ios, udp_socket::callback_t const& c
 	, m_cc(cc)
 	, m_resolver(ios)
 	, m_tunnel_packets(false)
+	, m_abort(false)
 {
-#ifndef NDEBUG
+#ifdef TORRENT_DEBUG
 	m_magic = 0x1337;
 #endif
 }
 
-#ifndef NDEBUG
+udp_socket::~udp_socket()
+{
+#ifdef TORRENT_DEBUG
+	TORRENT_ASSERT(m_magic == 0x1337);
+	TORRENT_ASSERT(!m_callback);
+	TORRENT_ASSERT(m_outstanding == 0);
+	m_magic = 0;
+#endif
+}
+
+#ifdef TORRENT_DEBUG
 	#define CHECK_MAGIC check_magic_ cm_(m_magic)
 	struct check_magic_
 	{
@@ -45,6 +88,9 @@ udp_socket::udp_socket(asio::io_service& ios, udp_socket::callback_t const& c
 void udp_socket::send(udp::endpoint const& ep, char const* p, int len, error_code& ec)
 {
 	CHECK_MAGIC;
+	// if the sockets are closed, the udp_socket is closing too
+	if (!m_ipv4_sock.is_open() && !m_ipv6_sock.is_open()) return;
+
 	if (m_tunnel_packets)
 	{
 		// send udp packets through SOCKS5 server
@@ -72,9 +118,9 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 		{
 			// "this" may be destructed in the callback
 			// that's why we need to unlock
-			l.unlock();
 			callback_t tmp = m_callback;
 			m_callback.clear();
+			l.unlock();
 		}
 		return;
 	}
@@ -84,6 +130,7 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 
 	if (e)
 	{
+		l.unlock();
 #ifndef BOOST_NO_EXCEPTIONS
 		try {
 #endif
@@ -94,6 +141,7 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 #ifndef BOOST_NO_EXCEPTIONS
 		} catch(std::exception&) {}
 #endif
+		l.lock();
 
 		// don't stop listening on recoverable errors
 		if (e != asio::error::host_unreachable
@@ -102,7 +150,19 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 			&& e != asio::error::connection_refused
 			&& e != asio::error::connection_aborted
 			&& e != asio::error::message_size)
+		{
+			if (m_outstanding == 0)
+			{
+				// "this" may be destructed in the callback
+				// that's why we need to unlock
+				callback_t tmp = m_callback;
+				m_callback.clear();
+				l.unlock();
+			}
 			return;
+		}
+
+		if (m_abort) return;
 
 		if (s == &m_ipv4_sock)
 			s->async_receive_from(asio::buffer(m_v4_buf, sizeof(m_v4_buf))
@@ -122,13 +182,23 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 #endif
 
 		if (m_tunnel_packets && m_v4_ep == m_proxy_addr)
+		{
+			l.unlock();
 			unwrap(e, m_v4_buf, bytes_transferred);
+		}
 		else
+		{
+			l.unlock();
 			m_callback(e, m_v4_ep, m_v4_buf, bytes_transferred);
+		}
+		l.lock();
 
 #ifndef BOOST_NO_EXCEPTIONS
 		} catch(std::exception&) {}
 #endif
+
+		if (m_abort) return;
+
 		s->async_receive_from(asio::buffer(m_v4_buf, sizeof(m_v4_buf))
 			, m_v4_ep, boost::bind(&udp_socket::on_read, this, s, _1, _2));
 	}
@@ -139,13 +209,23 @@ void udp_socket::on_read(udp::socket* s, error_code const& e, std::size_t bytes_
 #endif
 
 		if (m_tunnel_packets && m_v6_ep == m_proxy_addr)
+		{
+			l.unlock();
 			unwrap(e, m_v6_buf, bytes_transferred);
+		}
 		else
+		{
+			l.unlock();
 			m_callback(e, m_v6_ep, m_v6_buf, bytes_transferred);
+		}
 
 #ifndef BOOST_NO_EXCEPTIONS
 		} catch(std::exception&) {}
 #endif
+		l.lock();
+
+		if (m_abort) return;
+
 		s->async_receive_from(asio::buffer(m_v6_buf, sizeof(m_v6_buf))
 			, m_v6_ep, boost::bind(&udp_socket::on_read, this, s, _1, _2));
 	}
@@ -215,12 +295,15 @@ void udp_socket::unwrap(error_code const& e, char const* buf, int size)
 
 void udp_socket::close()
 {
+	mutex_t::scoped_lock l(m_mutex);	
 	TORRENT_ASSERT(m_magic == 0x1337);
 
 	error_code ec;
 	m_ipv4_sock.close(ec);
 	m_ipv6_sock.close(ec);
 	m_socks5_sock.close(ec);
+	m_resolver.cancel();
+	m_abort = true;
 	if (m_connection_ticket >= 0)
 	{
 		m_cc.done(m_connection_ticket);
@@ -232,6 +315,7 @@ void udp_socket::close()
 		// "this" may be destructed in the callback
 		callback_t tmp = m_callback;
 		m_callback.clear();
+		l.unlock();
 	}
 }
 
@@ -310,8 +394,7 @@ void udp_socket::set_proxy_settings(proxy_settings const& ps)
 		|| ps.type == proxy_settings::socks5_pw)
 	{
 		// connect to socks5 server and open up the UDP tunnel
-		tcp::resolver::query q(ps.hostname
-			, boost::lexical_cast<std::string>(ps.port));
+		tcp::resolver::query q(ps.hostname, to_string(ps.port).elems);
 		m_resolver.async_resolve(q, boost::bind(
 			&udp_socket::on_name_lookup, this, _1, _2));
 	}
@@ -326,6 +409,7 @@ void udp_socket::on_name_lookup(error_code const& e, tcp::resolver::iterator i)
 
 	m_proxy_addr.address(i->endpoint().address());
 	m_proxy_addr.port(i->endpoint().port());
+	l.unlock(); // on_connect may be called from within this thread
 	m_cc.enqueue(boost::bind(&udp_socket::on_connect, this, _1)
 		, boost::bind(&udp_socket::on_timeout, this), seconds(10));
 }
