@@ -56,7 +56,7 @@ void test_transfer(boost::intrusive_ptr<torrent_info> torrent_file, int proxy)
 	session_settings settings;
 	settings.ignore_limits_on_local_network = false;
 	ses.set_settings(settings);
-	ses.set_severity_level(alert::debug);
+	ses.set_alert_mask(~alert::progress_notification);
 	ses.listen_on(std::make_pair(51000, 52000));
 	ses.set_download_rate_limit(torrent_file->total_size() / 10);
 	remove_all("./tmp1");
@@ -124,6 +124,7 @@ void test_transfer(boost::intrusive_ptr<torrent_info> torrent_file, int proxy)
 
 	if (proxy) stop_proxy(8002);
 
+	TEST_CHECK(exists("./tmp1" / torrent_file->file_at(0).path));
 	remove_all("./tmp1");
 }
 
@@ -133,22 +134,22 @@ int test_main()
 	using namespace boost::filesystem;
 
 	try {
-		create_directory("test_torrent");
+		create_directory("test_torrent_dir");
 	} catch (std::exception&) {}
 
 	char random_data[300000];
 	std::srand(std::time(0));
 	std::generate(random_data, random_data + sizeof(random_data), &std::rand);
-	std::ofstream("./test_torrent/test1").write(random_data, 35);
-	std::ofstream("./test_torrent/test2").write(random_data, 16536 - 35);
-	std::ofstream("./test_torrent/test3").write(random_data, 16536);
-	std::ofstream("./test_torrent/test4").write(random_data, 17);
-	std::ofstream("./test_torrent/test5").write(random_data, 16536);
-	std::ofstream("./test_torrent/test6").write(random_data, 300000);
-	std::ofstream("./test_torrent/test7").write(random_data, 300000);
+	std::ofstream("./test_torrent_dir/test1").write(random_data, 35);
+	std::ofstream("./test_torrent_dir/test2").write(random_data, 16536 - 35);
+	std::ofstream("./test_torrent_dir/test3").write(random_data, 16536);
+	std::ofstream("./test_torrent_dir/test4").write(random_data, 17);
+	std::ofstream("./test_torrent_dir/test5").write(random_data, 16536);
+	std::ofstream("./test_torrent_dir/test6").write(random_data, 300000);
+	std::ofstream("./test_torrent_dir/test7").write(random_data, 300000);
 
 	file_storage fs;
-	add_files(fs, path("test_torrent"));
+	add_files(fs, path("test_torrent_dir"));
 
 	libtorrent::create_torrent t(fs, 16 * 1024);
 	t.add_url_seed("http://127.0.0.1:8000/");
@@ -175,8 +176,11 @@ int test_main()
 	for (int i = 0; i < 6; ++i)
 		test_transfer(torrent_file, i);
 	
+	torrent_file->rename_file(0, "./test_torrent_dir/renamed_test1");
+	test_transfer(torrent_file, 0);
+
 	stop_web_server(8000);
-	remove_all("./test_torrent");
+	remove_all("./test_torrent_dir");
 	return 0;
 }
 
